sequencetools.split_sequence_extended_to_weights_with_overhang
==============================================================

.. autofunction:: abjad.tools.sequencetools.split_sequence_extended_to_weights_with_overhang.split_sequence_extended_to_weights_with_overhang
